@@ -24,7 +24,7 @@
 int
 main (int argc, char *argv[])
 {
-	CouchDB *couchdb;
+	CouchdbSession *couchdb;
 	GSList *dblist, *sl;
 	GError *error = NULL;
 
@@ -32,21 +32,28 @@ main (int argc, char *argv[])
 	g_type_init ();
 	g_thread_init (NULL);
 
-	/* initialize CouchDB */
-	couchdb = couchdb_new (NULL);
+	/* Initialize Couchdb */
+	couchdb =  argc > 1 ? couchdb_session_new (argv[1]) : couchdb_session_new (NULL);
+	g_printf ("Connecting to Couchdb at %s\n", couchdb_session_get_uri (couchdb));
+	
 	if (!couchdb) {
-		g_print ("Could not create CouchDB object\n");
+		g_print ("Could not create Couchdb object\n");
 		return -1;
 	}
 
-	dblist = couchdb_list_databases (couchdb, &error);
+	dblist = couchdb_session_list_databases (couchdb, &error);
+	if (error != NULL) {
+		g_critical ("Error listing databases: %s", error->message);
+		g_error_free (error);
+	}
+	
 	for (sl = dblist; sl != NULL; sl = sl->next) {
-		CouchDBDatabaseInfo *dbinfo;
+		CouchdbDatabaseInfo *dbinfo;
 		GSList *doclist;
 
 		error = NULL;
 		g_print ("Found database %s\n", (const char *) sl->data);
-		dbinfo = couchdb_get_database_info (couchdb, (const char *) sl->data, &error);
+		dbinfo = couchdb_session_get_database_info (couchdb, (const char *) sl->data, &error);
 		if (dbinfo) {
 			g_print ("\tDatabase name: %s\n",
 				 couchdb_database_info_get_dbname (dbinfo));
@@ -68,14 +75,14 @@ main (int argc, char *argv[])
 
 		/* now, get list of documents */
 		error = NULL;
-		doclist = couchdb_list_documents (couchdb, (const char *) sl->data, &error);
+		doclist = couchdb_session_list_documents (couchdb, (const char *) sl->data, &error);
 		if (doclist) {
 			GSList *sl_doc;
 
 			g_print ("\tDocuments:\n");
 			for (sl_doc = doclist; sl_doc != NULL; sl_doc = sl_doc->next) {
-				CouchDBDocumentInfo *doc_info = sl_doc->data;
-				CouchDBDocument *document;
+				CouchdbDocumentInfo *doc_info = sl_doc->data;
+				CouchdbDocument *document;
 
 				error = NULL;
 				document = couchdb_document_get (couchdb,
@@ -105,7 +112,7 @@ main (int argc, char *argv[])
 		}
 	}
 
-	couchdb_free_database_list (dblist);
+	couchdb_session_free_database_list (dblist);
 	g_object_unref (G_OBJECT (couchdb));
 
 	return 0;
